package cn.net.caoyao.cpzshandset.service.presenter.impl.warehouse.out.common;

import java.util.ArrayList;
import java.util.List;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.os.Handler;
import android.os.Message;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;
import cilico.tools.barcode.PhoneScanner;
import cn.net.caoyao.cpzshandset.R;
import cn.net.caoyao.cpzshandset.bean.City;
import cn.net.caoyao.cpzshandset.bean.ConfigBean;
import cn.net.caoyao.cpzshandset.bean.SingleLabelOptionBean;
import cn.net.caoyao.cpzshandset.bean.WarehouseBean;
import cn.net.caoyao.cpzshandset.common.config.Config;
import cn.net.caoyao.cpzshandset.common.config.HandsetOperation;
import cn.net.caoyao.cpzshandset.common.config.HandsetVersionConstant;
import cn.net.caoyao.cpzshandset.common.config.RequestConstant;
import cn.net.caoyao.cpzshandset.common.config.TConfig;
import cn.net.caoyao.cpzshandset.common.util.LogUtil;
import cn.net.caoyao.cpzshandset.common.util.NetWorkUtils;
import cn.net.caoyao.cpzshandset.common.util.StringUtils;
import cn.net.caoyao.cpzshandset.service.bll.CityBll;
import cn.net.caoyao.cpzshandset.service.bll.SingleLabelBll;
import cn.net.caoyao.cpzshandset.service.bll.WarehouseBll;
import cn.net.caoyao.cpzshandset.service.bll.config.ConfigBll;
import cn.net.caoyao.cpzshandset.service.presenter.SingleLabelScannerConstact;
import cn.net.caoyao.cpzshandset.service.presenter.base.impl.SingleLabelScannerConstactImpl;
import cn.net.caoyao.cpzshandset.service.thread.ThreadReqTools;
import cn.net.caoyao.cpzshandset.service.tools.SaleAddressUtil;
import cn.net.caoyao.cpzshandset.ui.adapter.SingleLabelAdapter;
import cn.net.caoyao.cpzshandset.ui.dialog.TipsDialog;
import cn.net.caoyao.cpzshandset.ui.dialog.TipsDialog.DSure;
import cn.net.caoyao.cpzshandset.ui.weight.DialogUtils;
import cn.net.cpzslibs.prot.bean.res.ProtStatusResBean;

public class CommonOutWarehouseSingleLSPresenter extends SingleLabelScannerConstactImpl{

	private final SingleLabelScannerConstact.View sView;
	private Context context;
	private SingleLabelBll labelBll;
//	private ProductBll productBll;
	private WarehouseBll warehouseBll;
	private ConfigBll configBll;
	private WarehouseBean currentWarehouseBean;
	private CityBll cityBll;
	private SingleLabelAdapter adapter;
	private List<SingleLabelOptionBean> labels = new ArrayList<>();
	private int option_id;
	private int currentHansetVersion = HandsetVersionConstant.HANDSET_UNIVERSAL_VERSION_MODE;
	private int option_type = HandsetOperation.OPERATION_OUT_WAREHOUSE_CONSTANT.getOption();
	private TextView tv_scanner_text_identify1, tv_scanner_text_identify2, tv_scanner_text_identify3,
			tv_scanner_text_identify4;
	private TipsDialog tipsDialog;
	private ProgressDialog bProgressDialog = null;
	private Handler mHandler = new Handler() {
		@Override
		public void handleMessage(Message msg) {
			switch (msg.what) {
			case PhoneScanner.BARCODE_READ:
			case PhoneScanner.BARCODE_ERR_LABEL: // 成功
				scannerSuccess(msg.obj.toString());
				break;
			case PhoneScanner.BARCODE_NOREAD:
				// 数据扫描失败
				if (checkViewAvailable()) {
					sView.showMsgToast("取消扫描", Toast.LENGTH_SHORT);
				}
				break;
			case RequestConstant.REQUEST_FAIL:
				//请求失败
				if (!checkViewAvailable())return;
				dismissProgress();
				sView.showMsgToast("请求失败！", Toast.LENGTH_SHORT);
				break;
			case RequestConstant.REQUEST_FAIL_SOCKET_TIMEOUT:
				//超时
				if (!checkViewAvailable())return;
				dismissProgress();
				sView.showMsgToast("请求超时！", Toast.LENGTH_SHORT);
				break;
			case RequestConstant.REQUEST_PROT01_LOGIN_FAIL:
				//登录失败
				if (!checkViewAvailable())return;
				dismissProgress();
				String errorMsg = msg.obj.toString();
				int errorCode = msg.arg1;
				sView.showMsgToast(errorMsg + errorCode, Toast.LENGTH_SHORT);
				break;
			case RequestConstant.SUBMIT_ACTIVATE_WITHOUT_RES:
				//服务器没有返回值
				if (!checkViewAvailable()) return;
				dismissProgress();
				sView.showMsgToast("抱歉，服务器没有反馈，请重试或者联系工作人员", Toast.LENGTH_SHORT);
				break;
			case RequestConstant.SUBMIT_ACTIVATE_WITH_RES:
				//服务器没有返回值
				if (!checkViewAvailable()) return;
				dismissProgress();
				ProtStatusResBean resBean = (ProtStatusResBean) msg.obj;
				if (resBean.getResult() == 0) {
					sView.showMsgToast("上传数据成功！" , Toast.LENGTH_SHORT);
					sView.finishPage();
				} else {
					currentWarehouseBean = warehouseBll.queryWarehouseById(option_id, option_type);
					setLabelStatusData();
				}
				
				break;
			}

		}

	};

	@Override
	public void scannerSuccess(String str) {
		if (!checkViewAvailable())
			return;
		LogUtil.d(TConfig.Echo, "scannerRecuess：" + str);
//		sView.vibrate(100);
		super.scannerSuccess(str);
		if (StringUtils.isEmpty(str)) {
			sView.showMsgToast("扫描标签不能为空！", Toast.LENGTH_SHORT);
			return;
		}
		if (!StringUtils.isNumber(str)) {
			sView.showMsgToast("您所扫描的不是中国追溯的合法标签！", Toast.LENGTH_SHORT);
			return;
		}
		if (!(str.length() == 16)) {
			sView.showMsgToast("您所扫描的不是中国追溯的合法标签！"+ str.length(), Toast.LENGTH_SHORT);
			return;
		}
		
		if (labelBll.hasExistSingleLabelInAId(str, option_type, option_id)) {
			String tips = "本地已经存在未上传的出库标签：\n" + str;
			showIKnowTipsDialog(tips);
			return;
		}
		
		if (labelBll.isMaxLimitCount(option_type, option_id)) {
			String tips = "抱歉，本次出库列表已达到上限，请重新建立出库信息扫描";
			showIKnowTipsDialog(tips);
			return;
		}
//		LogUtil.d(TConfig.Echo, "option_type: " + option_type +"  option_id:"+option_id);
		labelBll.insertLabel(new SingleLabelOptionBean(str, option_type, option_id));
		labels = labelBll.queryAllLabelById(option_type, option_id);
		adapter.refreshData(labels);
		setLabelCountData();
		LogUtil.d(TConfig.Echo, "labels：" + labels.size());
	}

	private void showIKnowTipsDialog(String tips) {
		if (tipsDialog == null) {
			tipsDialog = new TipsDialog(context);
		}
		tipsDialog.show();
		tipsDialog.setWarnView("提示", tips, true, null);
	}
	
	private void showDelTipsDialog(final int position,String tipContent){
		if (tipsDialog == null) {
			tipsDialog = new TipsDialog(context);
		}
		tipsDialog.show();
		tipsDialog.setDelWarnView("提示", tipContent, position, false, new DSure() {
			
			@Override
			public void sureClick() {
				SingleLabelOptionBean b = labels.get(position);
				labelBll.deleteLabelByLabelId(b);
				labels = labelBll.queryAllLabelById(option_type, option_id);
				if (labels.size() == 0) {
					warehouseBll.updateWarehouseNotSubmitStatusById(option_id);
					setLabelStatusData();
				}
				adapter.refreshData(labels);
				setLabelCountData();
			}
		});
	}

	public CommonOutWarehouseSingleLSPresenter(SingleLabelScannerConstact.View sView, Context context, Intent intent) {
		super(sView, context);
		this.sView = sView;
		this.context = context;
		currentWarehouseBean = (WarehouseBean) intent.getSerializableExtra("currentWarehouseBean");
		option_id = currentWarehouseBean.getId();
		start();
	}

	@Override
	public void start() {
		if (!checkViewAvailable())
			return;
		init();
		View customView = LayoutInflater.from(context).inflate(R.layout.scanner_custom_diaplay_layout, null);
		initCustomView(customView);
		sView.setMoreOptionStr("上传");
		sView.setMoreOptionBtnVisiable(View.GONE);
		sView.setPageTitle("出库扫码");
		adapter = new SingleLabelAdapter(labels);
		sView.addHeadView(customView);
		sView.setAdapter(adapter);
		labels = labelBll.queryAllLabelById(option_type,
				currentWarehouseBean.getId());
		adapter.refreshData(labels);
		setLabelCountData();
		setLabelStatusData();
	}

	private void setLabelCountData() {
		tv_scanner_text_identify3.setText("标签数量：" + labels.size());
	}

	private void setLabelStatusData() {
		if (currentWarehouseBean.getStatus() == Config.SUBMIT_STATUS_NOT_SUBMIT) {
			tv_scanner_text_identify4.setText("状        态：未提交");
		} else {
			tv_scanner_text_identify4.setText("状        态：提交失败  错误码：" + currentWarehouseBean.getError_code() +"\n原        因："+ ThreadReqTools.getErrorMsg(currentWarehouseBean.getError_code()) );
		}
	}

	private void initCustomView(View v) {
		tv_scanner_text_identify1 = (TextView) v.findViewById(R.id.tv_scanner_text_identify1);
		tv_scanner_text_identify2 = (TextView) v.findViewById(R.id.tv_scanner_text_identify2);
		tv_scanner_text_identify3 = (TextView) v.findViewById(R.id.tv_scanner_text_identify3);
		tv_scanner_text_identify4 = (TextView) v.findViewById(R.id.tv_scanner_text_identify4);
		String describeStr = StringUtils.isEmpty(currentWarehouseBean.getDescribe()) ? "无":currentWarehouseBean.getDescribe();
		tv_scanner_text_identify1.setText("描        述："+describeStr);
		City mCity = cityBll.queryCityByCode(currentWarehouseBean.getSale_area_code());
		String salesArea = (mCity==null?"全国":SaleAddressUtil.getAddressStrByCity(mCity));
		tv_scanner_text_identify2.setText("销售区域：" + salesArea);
	
	}

	private void init() {
		labelBll = new SingleLabelBll(context);
		warehouseBll = new WarehouseBll(context);
		configBll = new ConfigBll(context);
		cityBll = new CityBll(context);
	}

	@Override
	public boolean checkViewAvailable() {
		boolean b = false;
		if (sView != null && context != null) {
			b = true;
		}
		return b;
	}

	@Override
	public Handler getHandler() {
		return mHandler;
	}

	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent data) {
		// TODO Auto-generated method stub

	}

	@Override
	public void onResume() {
		// TODO Auto-generated method stub

	}

	@Override
	public void backClick() {
		// TODO Auto-generated method stub

	}

	@Override
	public void btnScannerClick() {
		if (!checkViewAvailable())
			return;
		sView.readQRCode();
	}

	@Override
	public void uploadClick() {
		if (!checkViewAvailable()) return;
		ConfigBean configBean = configBll.queryConfigByHandsetMode(currentHansetVersion);
		if (configBean == null) {
			sView.showMsgToast("当前设备还未配置过手持机id，请先配置手持机的设备id", Toast.LENGTH_SHORT);
			return;
		}
		if (labels.size() <= 0){
			sView.showMsgToast("当前的出库单还没有标签，不能上传", Toast.LENGTH_SHORT);
			return;
		}
		if (!NetWorkUtils.isNetworkConnected(context)) {
			DialogUtils.showSetNetDialog(context);
			return;
		}
		
		showProgressDialog("提示", "正在提交出库信息，请稍后……");
//		long deviceId = Long.parseLong(ReadDeviceIDUtil.readScanDecrypt(configBean.getDeviceId()));
//		ThreadPoolManager.getThreadPool().execute(new CommonSubmitSingleActivateThread(mHandler, deviceId, activateBll, labelBll, currentActivate, labels));
	}
	
	public void dismissProgress() {
		if (bProgressDialog != null) {
			try {
				DialogUtils.dismissProgressDialog(bProgressDialog);
			} catch (Exception e) {
			}
		}
	}

	/**
	 * 提示正在更新数据
	 */
	protected void showProgressDialog(String titleStr, String tipsMsg) {
		bProgressDialog = DialogUtils.showProgressDialog(bProgressDialog, titleStr,
				tipsMsg, context);
	}

	@Override
	public void onItemClickLinstener(int position) {
//		int currentPos = labels.size() - position - 1;
		if (position > 0) {
			SingleLabelOptionBean b = labels.get(position - 1);
			String tipsContent = "确认删除出库标签：\n" + b.getLabel_id();
			showDelTipsDialog(position -1,tipsContent);
		}
		
	}

	@Override
	public void onItemLongClickListener(int position) {
		

	}

}
